ProgramError

Enum ProgramError 

pub enum ProgramError {
Show 21 variants AlreadyLoaded, NotLoaded, AlreadyAttached, NotAttached, LoadError { io_error: Error, verifier_log: VerifierLog, }, SyscallError(SyscallError), UnknownInterface { name: String, }, UnexpectedProgramType, MapError(MapError), KProbeError(KProbeError), UProbeError(UProbeError), TracePointError(TracePointError), SocketFilterError(SocketFilterError), XdpError(XdpError), TcError(TcError), ExtensionError(ExtensionError), Btf(BtfError), InvalidName { name: String, }, IOError(Error), AttachCookieNotSupported, NetlinkError(NetlinkError),
}
Error type returned when working with programs.

Variants



AlreadyLoaded

The program is already loaded.



NotLoaded

The program is not loaded.



AlreadyAttached

The program is already attached.



NotAttached

The program is not attached.



LoadError

Loading the program failed.

Fields

io_error: Error

The io::Error returned by the BPF_PROG_LOAD syscall.

verifier_log: VerifierLog

The error log produced by the kernel verifier.



SyscallError(SyscallError)

A syscall failed.



UnknownInterface

The network interface does not exist.

Fields

name: String

interface name



UnexpectedProgramType

The program is not of the expected type.



MapError(MapError)

A map error occurred while loading or attaching a program.



KProbeError(KProbeError)

An error occurred while working with a KProbe.



UProbeError(UProbeError)

An error occurred while working with an UProbe.



TracePointError(TracePointError)

An error occurred while working with a TracePoint.



SocketFilterError(SocketFilterError)

An error occurred while working with a SocketFilter.



XdpError(XdpError)

An error occurred while working with an Xdp program.



TcError(TcError)

An error occurred while working with a TC program.



ExtensionError(ExtensionError)

An error occurred while working with an Extension program.



Btf(BtfError)

An error occurred while working with BTF.



InvalidName

The program is not attached.

Fields

name: String

program name



IOError(Error)

An error occurred while working with IO.



AttachCookieNotSupported

Providing an attach cookie is not supported.



NetlinkError(NetlinkError)

An error occurred while working with Netlink.